@@ -1,4 +1,4 @@
-from tokenize import NAME, OP, INDENT, NEWLINE, DEDENT, STRING, ERRORTOKEN
+from tokenize import NAME, OP, INDENT, NEWLINE, STRING
 from tokenize import generate_tokens
 
 ########################
@@ -10,7 +10,7 @@ def tokens_in(s, strip_it=True):
     def get():
         if closure['processed']:
             return ''
-        
+
         closure['processed'] = True
         if strip_it:
             return s.strip()
@@ -25,12 +25,12 @@ def tokens_in(s, strip_it=True):
 class Tokens(object):
     def __init__(self, default_kls):
         self.default_kls = tokens_in(default_kls)
-        
+
         self.equivalence = {
               'after_each' : 'tearDown'
             , 'before_each' : 'setUp'
             }
-             
+
         self.before_each = [
               (NAME, 'def')
             , (NAME, self.equivalence['before_each'])
@@ -38,7 +38,7 @@ class Tokens(object):
             , (NAME, 'self')
             , (OP, ')')
             ]
-        
+
         self.after_each = [
               (NAME, 'def')
             , (NAME, self.equivalence['after_each'])
@@ -46,36 +46,36 @@ class Tokens(object):
             , (NAME, 'self')
             , (OP, ')')
             ]
-        
+
         self.test_skip = [
               (NAME, 'raise')
             , (NAME, 'nose.SkipTest')
             ]
-    
+
     ########################
     ###   MAKERS
     ########################
-    
+
     def make_single(self, name, args):
         lst = [ (NAME, 'def')
               , (NAME, name)
               , (OP, '(')
               ]
-        
+
         if args:
             lst.extend(args[0])
-            
+
             for arg in args[1:]:
                 lst.append((OP, ','))
                 lst.extend(arg)
-        
+
         lst.extend(
             [ (OP, ')')
             , (OP, ':')
             ]
         )
         return lst
-    
+
     def make_describe(self, kls, name):
         lst = [ (NAME, 'class')
                  , (NAME, name)
@@ -85,21 +85,21 @@ class Tokens(object):
             lst.extend(tokens_in(kls))
         else:
             lst.extend(self.default_kls)
-        
+
         lst.extend(
             [ (OP, ')')
             , (OP, ':')
             ]
         )
-        
+
         return lst
-    
+
     def make_super(self, indent, kls, method):
         if kls:
             kls = tokens_in(kls)
         else:
             kls = self.default_kls
-            
+
         method_name = 'noy_sup_%s' % self.equivalence[method]
         result = [ (OP, ':')
                  , (NEWLINE, '\n')
@@ -109,9 +109,9 @@ class Tokens(object):
                  , (NAME, 'super')
                  , (OP, '(')
                  ]
-        
+
         result.extend(kls)
-        
+
         result.extend(
             [ (OP, ',')
             , (NAME, 'self')
@@ -119,9 +119,9 @@ class Tokens(object):
             , (OP, ')')
             ]
         )
-        
+
         return result
-    
+
     def make_describe_attr(self, describe):
         return [ (NEWLINE, '\n')
                , (NAME, describe)
@@ -130,27 +130,27 @@ class Tokens(object):
                , (OP, '=')
                , (NAME, 'True')
                ]
-    
+
     def make_name_modifier(self, ismethod, cleaned, english):
         result = [ (NEWLINE, '\n') ]
-        
+
         parts = cleaned.split('.')
         result.append((NAME, parts[0]))
-        
+
         for part in parts[1:]:
             result.extend(
                 [ (OP, '.')
                 , (NAME, part)
                 ]
             )
-        
+
         if ismethod:
             result.extend(
                 [ (OP, '.')
                 , (NAME, "__func__")
                 ]
             )
-        
+
         result.extend(
             [ (OP, '.')
             , (NAME, "__testname__")
@@ -158,9 +158,9 @@ class Tokens(object):
             , (STRING, english)
             ]
         )
-        
+
         return result
-    
+
     def wrap_setup(self, class_name, typ):
         """Described.typ = noy_wrap_typ(Described, Described.typ)"""
         equivalence = self.equivalence[typ]
@@ -179,9 +179,10 @@ class Tokens(object):
             , (NAME, equivalence)
             , (OP, ")")
             ]
-    
+
     def wrap_after_each(self, class_name):
         return self.wrap_setup(class_name, "after_each")
-    
+
     def wrap_before_each(self, class_name):
         return self.wrap_setup(class_name, "before_each")
+
